matminer.featurizers.site.tests package — matminer 0.7.0 documentation

# matminer.featurizers.site.tests package

## Submodules

## matminer.featurizers.site.tests.base module

class `matminer.featurizers.site.tests.base.` `SiteFeaturizerTest`(methodName='runTest')

  Bases: `pymatgen.util.testing.PymatgenTest`

  `setUp`()

    Hook method for setting up the test fixture before exercising it.

  `tearDown`()

    Hook method for deconstructing the test fixture after testing it.

## matminer.featurizers.site.tests.test_bonding module

class `matminer.featurizers.site.tests.test_bonding.` `BondingTest`(methodName='runTest')

  Bases: `matminer.featurizers.site.tests.base.SiteFeaturizerTest`

  `test_AverageBondAngle`()
  `test_AverageBondLength`()
  `test_bop`()

## matminer.featurizers.site.tests.test_chemical module

class `matminer.featurizers.site.tests.test_chemical.` `ChemicalSiteTests`(methodName='runTest')

  Bases: `matminer.featurizers.site.tests.base.SiteFeaturizerTest`

  `test_chemicalSRO`()
  `test_ewald_site`()
  `test_local_prop_diff`()
  `test_site_elem_prop`()

## matminer.featurizers.site.tests.test_external module

class `matminer.featurizers.site.tests.test_external.` `ExternalSiteTests`(methodName='runTest')

  Bases: `matminer.featurizers.site.tests.base.SiteFeaturizerTest`

  `test_SOAP`()

## matminer.featurizers.site.tests.test_fingerprint module

class `matminer.featurizers.site.tests.test_fingerprint.` `FingerprintTests`(methodName='runTest')

  Bases: `matminer.featurizers.site.tests.base.SiteFeaturizerTest`

  `test_chemenv_site_fingerprint`()
  `test_crystal_nn_fingerprint`()
  `test_dataframe`()
  `test_off_center_cscl`()
  `test_op_site_fingerprint`()
  `test_simple_cubic`()

    Test with an easy structure

  `test_voronoifingerprint`()

## matminer.featurizers.site.tests.test_misc module

class `matminer.featurizers.site.tests.test_misc.` `MiscSiteTests`(methodName='runTest')

  Bases: `matminer.featurizers.site.tests.base.SiteFeaturizerTest`

  `test_cns`()
  `test_interstice_distribution_of_crystal`()
  `test_interstice_distribution_of_glass`()

## matminer.featurizers.site.tests.test_rdf module

class `matminer.featurizers.site.tests.test_rdf.` `RDFTests`(methodName='runTest')

  Bases: `matminer.featurizers.site.tests.base.SiteFeaturizerTest`

  `test_afs`()
  `test_gaussiansymmfunc`()
  `test_grdf`()

## Module contents